@@ -7,7 +7,7 @@ use Example::Syntax;
 extends 'Example::Controller';
 
 sub root :At('$path_end/...') Via('../protected')  ($self, $c, $user) {
-  $c->action->next($user->account);
+  $c->action->next(my $account = $user->account);
 }
 
   sub prepare_edit :At('...') Via('root') ($self, $c, $account) { 
@@ -15,14 +15,12 @@ sub root :At('$path_end/...') Via('../protected')  ($self, $c, $user) {
     $c->action->next($account);
   }
 
-    sub edit :Get('edit') Via('prepare_edit') ($self, $c, $account) {
-      return  $c->view->set_http_ok;
-    }
+    # GET /account
+    sub edit :Get('edit') Via('prepare_edit') ($self, $c, $account) { return }
 
+    # PATCH /account
     sub update :Patch('') Via('prepare_edit') BodyModel ($self, $c, $account, $bm) {
-      return $account->update_account($bm) ?
-        $c->view->set_http_ok : 
-          $c->view->set_http_bad_request;
+      return $account->set_from_request($bm);
     }
 
 __PACKAGE__->meta->make_immutable;
