@@ -6,7 +6,7 @@ use Example::Syntax;
 
 extends 'Example::Controller';
 
-has post_login_action => (is=>'ro', isa=>'Str', default=>'/home/user_home');
+has post_login_action => (is=>'ro', isa=>'Str', default=>'/home/user_show');
 
 sub root :At('login/...') Via('../root') ($self, $c, $user) {
   return $c->redirect_to_action($self->post_login_action) && $c->detach
@@ -19,17 +19,16 @@ sub root :At('login/...') Via('../root') ($self, $c, $user) {
     $c->action->next($user);
   }
 
-    sub build :Get('') Via('prepare_build') ($self, $c, $user) {   }
+    # GET /login/new
+    sub build :Get('new') Via('prepare_build') ($self, $c, $user) {   }
 
+    # POST /login
     sub create :Post('') Via('prepare_build') BodyModel ($self, $c, $user, $bm) {
-
-    use Devel::Dwarn;  Dwarn $bm->nested_params;
-
-      return $c->authenticate($user, $bm) ?
-        $c->redirect_to_action($self->post_login_action) :
-          $c->view->http_bad_request;
+      return $c->redirect_to_action($self->post_login_action)
+        if $c->authenticate($user, $bm);
     }
 
+# GET /logout
 sub logout :Get('logout') Via('../protected') ($self, $c, $user) {
   return $c->logout && $c->redirect_to_action('build');
 }
