@@ -9,43 +9,39 @@ extends 'Example::Controller';
 
 # /todos/...
 sub root :At('$path_end/...') Via('../protected') ($self, $c, $user) {
-  $c->action->next(my $collection = $user->todos);
+  $c->action->next(my $todos = $user->todos);
 }
 
   # /todos/...
-  sub search :At('/...') Via('root') QueryModel ($self, $c, $collection, $todo_query) {
-    my $sessioned_query = $c->model('Todos::Session', $todo_query);
-    $collection = $collection->filter_by_request($sessioned_query);
-    $c->action->next($collection);
+  sub search :At('/...') Via('root') QueryModel ($self, $c, $todos, $todo_query) {
+    $todos = $todos->filter_by_request($todo_query);
+    $c->action->next($todos);
   }
 
     # GET /todos
-    sub list :Get('') Via('search') ($self, $c, $collection) {
+    sub list :Get('') Via('search') ($self, $c, $todos) {
       return $self->view(
-        list => $collection,
-        todo => $collection->new_todo,
-      )->set_http_ok;
+        list => $todos,
+        todo => $todos->new_todo,
+      );
     }
 
   # /todos/...
-  sub prepare_build :At('/...') Via('search') ($self, $c, $collection) {
+  sub prepare_build :At('/...') Via('search') ($self, $c, $todos) {
     $self->view_for('list',
-      list => $collection,
-      todo => my $new_todo = $collection->new_todo
+      list => $todos,
+      todo => my $new_todo = $todos->new_todo
     );
     $c->action->next($new_todo);
   }
 
     # GET /todos/new
-    sub build :Get('new') Via('prepare_build') ($self, $c, $new_todo) {
-      return $c->view->set_http_ok;
-    }
+    sub build :Get('new') Via('prepare_build') ($self, $c, $new_todo) { return }
 
     # POST /todos/
     sub create :Post('') Via('prepare_build') BodyModel ($self, $c, $new_todo, $bm) {
-      return $new_todo->set_from_request($bm) ?
-        $c->view->clear_todo && $c->view->set_http_ok :
-          $c->view->set_http_bad_request;
+      return $c->view->clear_todo && $c->view->set_list_to_last_page
+        if $new_todo->set_from_request($bm)->valid;
     }
 
   # /todos/{:Int}/...
@@ -61,15 +57,11 @@ sub root :At('$path_end/...') Via('../protected') ($self, $c, $user) {
     }
 
       # GET /todos/{:Int}/edit
-      sub edit :Get('edit') Via('prepare_edit') ($self, $c, $todo) {
-        return $c->view->set_http_ok;
-      }
+      sub edit :Get('edit') Via('prepare_edit') ($self, $c, $todo) { return }
     
       # PATCH /todos/{:Int}
       sub update :Patch('') Via('prepare_edit') BodyModelFor('create') ($self, $c, $todo, $bm) {
-        return $todo->set_from_request($bm) ?
-          $c->view->set_http_ok :
-            $c->view->set_http_bad_request;
+        return $todo->set_from_request($bm);
       }
 
 __PACKAGE__->meta->make_immutable;
